* Set up target folder and create /input and /output subfolders
*cd "XXX"

clear all
set mem 40m
set more off
pause on

	*Baseline 		if treatment==1 sessions: 2, 3, 11, 12
	*Human central banker 	if treatment==2 sessions: 4, 5, 6, 14
	*Menu cost		if treatment==3 sessions: 7, 8, 9, 10
	*Low friction		if treatment==4 sessions: 13, 15, 16, 17	

global scripts = c(pwd)
global input 	"./input"
global output 	"./output"

	
*****************************************************************************************************************************************************
use "$input/exp_data_1-17_ver5.dta" 

drop if session==1
drop if initializ==1
gen time = period - 3

* Welfare by session
egen welfare_temp_session = mean(abutility) if time >=1, by(period treatment session)
gen welfare_ses = welfare_temp_session/10000

preserve
	keep if subject == 4
	
	collapse (mean) realgdp (mean) inflation (mean) welfare = welfare_ses, by(treatment time)
	
	foreach var of varlist realgdp inflation welfare {
		gen `var'_base = `var' if treatment == 1
		gen `var'_human = `var' if treatment == 2
		gen `var'_menu = `var' if treatment == 3
		gen `var'_no_fric = `var' if treatment == 4
	}
	*
		
	* Figure 3 - Real GDP - Experiment
	graph twoway (line realgdp_base realgdp_human realgdp_menu realgdp_no_fric time if time<=50 & time>0, clcolor(black brown blue green) clpattern(solid longdash_dot shortdash dash) ),ytitle("ECU") xtitle("period") ///
	yscale(range(400 1400)) ylabel(400(200)1400) graphregion(margin(small) color(white)) legend(order(1 "Baseline" 2 "Human Central Banker" 3 "Menu Cost" 4 "Low Friction") ) 
	capture graph export "$output/fig3_realgdp_experiment.png",  replace
	capture graph export "$output/fig3_realgdp_experiment.eps",  replace
		
	* Figure 4 - welfare graphs - Experiment
	graph twoway (line welfare_base welfare_human welfare_menu welfare_no_fric time if time<=50 & time>0, clcolor(black brown blue green) clpattern(solid longdash_dot shortdash dash)), ytitle("Euro") ///
	 xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Baseline" 2 "Human Central Banker" 3 "Menu Cost" 4 "Low Friction")) 
	capture graph export "$output/fig4_welfare_new_experiment.png",  replace
	capture graph export "$output/fig4_welfare_new_experiment.eps",  replace
	
	* Figure 5 - Inflation graphs - Experiment
	graph twoway (line inflation_base inflation_human inflation_menu inflation_no_fric time if time<=50 & time>0, clcolor(black brown blue green) clpattern(solid longdash_dot shortdash dash)), ytitle("Inflation %") ///
	 xtitle("period") xlabel(0(5)50) xmtick(1(1)50) graphregion(margin(small) color(white)) legend(order(1 "Baseline" 2 "Human Central Banker" 3 "Menu Cost" 4 "Low Friction")) 
	graph export "$output/fig5_inflation_experiment.png", replace as(png)
	graph export "$output/fig5_inflation_experiment.eps", replace as(eps)
	
restore


*****************************************************************************************************************************************************
* Input for Table 4

gen treat = "baseline "	 	if treatment==1 
replace treat = "human"  	if treatment==2
replace treat = "menu" 		if treatment==3
replace treat = "low" 		if treatment==4 

collapse (mean) realgdp_ses_mean = realgdp (mean) welfare_ses_mean = welfare_ses (mean) inflation_ses_mean = inflation if time >=1, by(treatment treat session)

bysort treat: gen ses_im = _n

preserve
	
	import excel using "$input/simulations_clean.xlsx", firstrow clear
	* Import new simulations
	
	gen treatment = 5
	
	* Adjust period for simulated data, similarly as for experimental data
	gen time = ppp-3
	
	drop if time <=0
	
	collapse sim*
	
	gen treat = "sim"
	
	expand 4
	
	gen ses_im = _n
	
	tempfile simulated_data_new
	save `simulated_data_new', replace
restore


merge m:1 ses_im using `simulated_data_new'

drop _merge session treatment

replace treat = strrtrim(treat)

replace treat = "_" + treat

reshape wide inflation* realgdp* welfare* sim*, i(ses_im) j(treat) string

keep ses_im inflation* realgdp* welfare* ///
sim_gdp_base_baseline sim_welfare_base_baseline sim_inflation_base_baseline sim_gdp_menu_baseline sim_welfare_menu_baseline sim_inflation_menu_baseline sim_gdp_no_fric_baseline sim_welfare_no_fric_baseline sim_inflation_no_fric_baseline

export excel using "$output/session_averages_for_test_2019_08_07.xls", firstrow(variables) replace



*****************************************************************************************************************************************************
* Simulations
import excel using "$input/simulations_clean.xlsx", firstrow clear
	
* Adjust period for simulated data, similarly as for experimental data
gen time = ppp-3
	
* Figure 1 - Real GDP - Simulated
graph twoway (line sim_gdp_base sim_gdp_menu sim_gdp_no_fric time if time<=50 & time>0, clcolor(black lavender khaki) clpattern("--.." dash dash) ),ytitle("ECU") xtitle("period") ///
 graphregion(margin(small) color(white)) legend(order(1 "Simulated Baseline" 2 "Simulated Menu Cost" 3 "Simulated Low Friction")) 
capture graph export "$output/fig1_realgdp_simulated.png",  replace
capture graph export "$output/fig1_realgdp_simulated.eps",  replace


* Figure 2 - Inflation graphs - Simulated
graph twoway (line sim_inflation_base sim_inflation_menu sim_inflation_no_fric time if time<=50 & time>0, clcolor(black lavender khaki) clpattern("--.." dash dash)), ytitle("Inflation %") ///
 xtitle("period") xlabel(0(5)50) xmtick(1(1)50) graphregion(margin(small) color(white)) legend(order(1 "Simulated Baseline" 2 "Simulated Menu Cost" 3 "Simulated Low Friction")) 
*capture graph export inflation_sim3.png,  replace
graph export "$output/fig2_inflation_simulated.png", replace as(png)
graph export "$output/fig2_inflation_simulated.eps", replace as(eps)


* Figure A.3 - Welfare graphs - Simulated
graph twoway (line sim_welfare_base sim_welfare_menu sim_welfare_no_fric time if time<=50 & time>0, clcolor(black lavender khaki) clpattern("--.." dash dash)), ytitle("Euro") ///
yscale(range(0.8 1.8)) ylabel(0.8(0.2)1.8) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Simulated Baseline" 2 "Simulated Menu Cost" 3 "Simulated Low Friction")) 
capture graph export "$output/figa3_welfare_simulated.png",  replace
capture graph export "$output/figa3_welfare_simulated.eps",  replace

*****************************************************************************************************************************************************
* Additional figures

* Read in data
use "$input/exp_data_1-17_ver5.dta", clear

drop if session==1
drop if initializ==1
gen time = period - 3

* Welfare by session
egen welfare_temp_session = mean(abutility) if time >=1, by(period treatment session)
gen welfare_ses = welfare_temp_session/10000

* Inflation by session
egen inflation_ses=mean(inflation) if time >=1, by(period treatment session)

* Real GDP by session
egen realgdp_ses=mean(realgdp) if time >=1, by(period treatment session)

* Employment
egen empl_ses = max(empl) if time >=1, by(period treatment session)

* keep only one subject for graph
keep if subject == 4


* Generate session level variables

foreach var of varlist welfare_ses inflation_ses realgdp_ses empl_ses {
		
		egen std`var'=std(`var')
			
		gen `var'_base_s1 = `var' if treatment == 1 & session == 2
		gen `var'_base_s2 = `var' if treatment == 1 & session == 3
		gen `var'_base_s3 = `var' if treatment == 1 & session == 11
		gen `var'_base_s4 = `var' if treatment == 1 & session == 12
		
		gen `var'_human_cb_s1 = `var' if treatment == 2 & session == 4
		gen `var'_human_cb_s2 = `var' if treatment == 2 & session == 5
		gen `var'_human_cb_s3 = `var' if treatment == 2 & session == 6
		gen `var'_human_cb_s4 = `var' if treatment == 2 & session == 14
			
		gen `var'_menu_s1 = `var' if treatment == 3 & session == 7
		gen `var'_menu_s2 = `var' if treatment == 3 & session == 8
		gen `var'_menu_s3 = `var' if treatment == 3 & session == 9
		gen `var'_menu_s4 = `var' if treatment == 3 & session == 10
		
		gen `var'_no_fric_s1 = `var' if treatment == 4 & session == 13
		gen `var'_no_fric_s2 = `var' if treatment == 4 & session == 15
		gen `var'_no_fric_s3 = `var' if treatment == 4 & session == 16
		gen `var'_no_fric_s4 = `var' if treatment == 4 & session == 17

}
*
* Figure A.1

* Real GDP Baseline
graph twoway (line realgdp_ses_base_s* time if treatment == 1 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("ECU") ///
yscale(range(0 1200)) ylabel(0(200)1200) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa1_realgdp_baseline.png",  replace
capture graph export "$output/figa1_realgdp_baseline.eps",  replace

* Real GDP Human CB
graph twoway (line realgdp_ses_human_cb_s* time if treatment == 2 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("ECU") ///
yscale(range(0 1200)) ylabel(0(200)1200) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa1_realgdp_human_cb.png",  replace
capture graph export "$output/figa1_realgdp_human_cb.eps",  replace

* Real GDP Menu Cost
graph twoway (line realgdp_ses_menu_s* time if treatment == 3 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("ECU") ///
yscale(range(0 1200)) ylabel(0(200)1200) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa1_realgdp_menu.png",  replace
capture graph export "$output/figa1_realgdp_menu.eps",  replace

* Real GDP Low Friction
graph twoway (line realgdp_ses_no_fric_s* time if treatment == 4 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("ECU") ///
yscale(range(0 1200)) ylabel(0(200)1200) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa1_realgdp_low_fric.png",  replace
capture graph export "$output/figa1_realgdp_low_fric.eps",  replace


* Welfare Baseline
graph twoway (line welfare_ses_base_s* time if treatment == 1 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("Euro") ///
yscale(range(0.2 1.8)) ylabel(0.2(0.2)1.8) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa1_welfare_baseline.png",  replace
capture graph export "$output/figa1_welfare_baseline.eps",  replace

* Welfare Human CB
graph twoway (line welfare_ses_human_cb_s* time if treatment == 2 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("Euro") ///
yscale(range(0.2 1.8)) ylabel(0.2(0.2)1.8) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa1_welfare_human_cb.png",  replace
capture graph export "$output/figa1_welfare_human_cb.eps",  replace

* Welfare Menu Cost
graph twoway (line welfare_ses_menu_s* time if treatment == 3 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("Euro") ///
yscale(range(0.2 1.8)) ylabel(0.2(0.2)1.8) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa1_welfare_menu.png",  replace
capture graph export "$output/figa1_welfare_menu.eps",  replace

* Welfare Low Friction
graph twoway (line welfare_ses_no_fric_s* time if treatment == 4 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("Euro") ///
yscale(range(0.2 1.8)) ylabel(0.2(0.2)1.8) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa1_welfare_low_fric.png",  replace
capture graph export "$output/figa1_welfare_low_fric.eps",  replace

* Figure A.2

* Inflation Baseline
graph twoway (line inflation_ses_base_s* time if treatment == 1 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("Inflation %") ///
 xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa2_inflation_baseline.png",  replace
capture graph export "$output/figa2_inflation_baseline.eps",  replace

* Inflation Human CB
graph twoway (line inflation_ses_human_cb_s* time if treatment == 2 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("Inflation %") ///
 xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa2_inflation_human_cb.png",  replace
capture graph export "$output/figa2_inflation_human_cb.eps",  replace

* Inflation Menu Cost
graph twoway (line inflation_ses_menu_s* time if treatment == 3 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("Inflation %") ///
 xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa2_inflation_menu.png",  replace
capture graph export "$output/figa2_inflation_menu.eps",  replace

* Inflation Low Friction
graph twoway (line inflation_ses_no_fric_s* time if treatment == 4 & time<=50 & time>0, clcolor(black brown blue green) clpattern(solid dash longdash_dot "--..")), ytitle("Inflation %") ///
 xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4")) 
capture graph export "$output/figa2_inflation_low_fric.png",  replace
capture graph export "$output/figa2_inflation_low_fric.eps",  replace

* Prep for employment figures

* Merge Simulated Employment data from Excel for Bseline, Menu Cost, and Low Friction
preserve
	* Import new simulations
	import excel using "$input/simulations_2019_03_25.xlsx", firstrow clear sheet("Baseline")
	
	* Adjust period for simulated data, similarly as for experimental data
	gen time = Period-3
	
	keep time empl
	rename empl sim_empl_base
	
	tempfile simulated_data
	save `simulated_data', replace
restore

merge m:1 time using `simulated_data'
keep if _merge == 1 | _merge == 3
drop _merge

preserve
	
	* Import new simulations
	import excel using "$input/simulations_2019_03_25.xlsx", firstrow clear sheet("menu cost")
	
	* Adjust period for simulated data, similarly as for experimental data
	gen time = Period-3
	
	keep time empl
	rename empl sim_empl_menu
	
	tempfile simulated_data
	save `simulated_data', replace
restore

merge m:1 time using `simulated_data'
keep if _merge == 1 | _merge == 3
drop _merge

preserve
	
	* Import new simulations
	import excel using "$input/simulations_2019_03_25.xlsx", firstrow clear sheet("Low friction")
	
	* Adjust period for simulated data, similarly as for experimental data
	gen time = Period-3
	
	keep time empl
	rename empl sim_empl_no_fric
	
	tempfile simulated_data
	save `simulated_data', replace
restore

merge m:1 time using `simulated_data'
keep if _merge == 1 | _merge == 3
drop _merge

* Figure A.2 continued

* Employment Baseline
graph twoway (line empl_ses_base_s* sim_empl_base time if treatment == 1 & time<=50 & time>0, clcolor(black brown blue green lavender) clpattern(solid dash longdash_dot "--.." solid)), ytitle("Employment") ///
yscale(range(0 21)) ylabel(0(5)20) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4" 5 "Simulated")) 
capture graph export "$output/figa2_employ_baseline.png",  replace
capture graph export "$output/figa2_employ_baseline.eps",  replace

* Employment Human CB
graph twoway (line empl_ses_human_cb_s* sim_empl_base time if treatment == 2 & time<=50 & time>0, clcolor(black brown blue green lavender) clpattern(solid dash longdash_dot "--.." solid)), ytitle("Employment") ///
yscale(range(0 21)) ylabel(0(5)20) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4" 5 "Simulated")) 
capture graph export "$output/figa2_employ_human_cb.png",  replace
capture graph export "$output/figa2_employ_human_cb.eps",  replace

* Employment Menu Cost
graph twoway (line empl_ses_menu_s* sim_empl_menu time if treatment == 3 & time<=50 & time>0, clcolor(black brown blue green lavender) clpattern(solid dash longdash_dot "--..")), ytitle("Employment") ///
yscale(range(0 21)) ylabel(0(5)20) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4" 5 "Simulated")) 
capture graph export "$output/figa2_employ_menu.png",  replace
capture graph export "$output/figa2_employ_menu.eps",  replace

* Employment Low Friction
global scripts = c(pwd)
global input 	"./input"
global output 	"./output"

egen shs1=sum(hs1) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)
egen shs2=sum(hs2) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)
egen shs3=sum(hs3) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)

egen sumsavings=sum(savings) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)

gen prod=prodfun/stock

drop if session==1
drop if treatment!=4
drop if initializ==1

drop if subject==1
drop if subject==2
drop if subject==3
drop if subject==7
drop if subject==8
drop if subject==9

xtset id period

gen dwage=-labval/stock-agrwage
gen dprice=price-avgpriceall
gen realinterest=interest-inflation

*individual wages
gen wage=-labval/stock

*consumption calculation
gen cons=quantity1+quantity2+quantity3
gen consumption=quantity1*pprice1+quantity2*pprice2+quantity3*pprice3

*descriptive stat for consumers

gen wwage=-wage
sum wwage
sum stock
sum savings
sum sumsavings if subject==4
sum utility

sum quantity1
sum quantity2
sum quantity3
sum cons
sum consumption

gen work=10-stock
sum work

	
graph twoway (line empl_ses_no_fric_s* sim_empl_no_fric time if treatment == 4 & time<=50 & time>0, clcolor(black brown blue green lavender) clpattern(solid dash longdash_dot "--..")), ytitle("Employment") ///
yscale(range(0 21)) ylabel(0(5)20) xtitle("period") graphregion(margin(small) color(white)) legend(order(1 "Session 1" 2 "Session 2" 3 "Session 3" 4 "Session 4" 5 "Simulated")) 
capture graph export "$output/figa2_employ_low_fric.png",  replace
capture graph export "$output/figa2_employ_low_fric.eps",  replace



* Online appendix
*****************************************************************************************************************************************************
use "$input/exp_data_1-17_ver5.dta", clear


egen shs1=sum(hs1) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)
egen shs2=sum(hs2) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)
egen shs3=sum(hs3) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)

egen sumsavings=sum(savings) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)

gen prod=prodfun/stock

drop if session==1
drop if initializ==1

drop if subject==4
drop if subject==5
drop if subject==6
drop if subject==7
drop if subject==8
drop if subject==9

xtset id period

gen lprice=l.price
generate pricediff=price-l.price if subject==1 | subject==2 | subject==3
generate rpricediff=(price-l.price)/l.price if subject==1 | subject==2 | subject==3

generate prodmsales=prodfun-sales
gen dwage=-labval/stock-agrwage
gen dprice=price-avgpriceall
gen realinterest=interest-inflation

*individual wages
gen wage=-labval/stock

*market wages

egen sumlabval=sum(labval) if subject==1 | subject==2 | subject==3, by(period session)
egen sumstock=sum(stock) if subject==1 | subject==2 | subject==3, by(period session)
gen marketwage=-sumlabval/sumstock

gen dmwage=wage-marketwage

* Table B.1 - Descriptive statistics - Pooled
preserve
	*OUTLIERS
	*drop if session==7 & period==12 & subject==3
	*drop if session==7 & period==18 & subject==3
	*drop if session==7 & period==19 & subject==3
	*drop if session==9 & period==31 & subject==1

	sum interest if subject==1
	sum inflation if subject==1
	sum gap if subject==1
	sum gdp if subject==1
	sum realgdp if subject==1
	sum rgdpg if subject==1

	sum stock
	sum price
	sum profits
	sum prodfun
	sum sales
	sum prodmsales
	sum wage
	sum dmwage
	sum markup_price if markup_price > -1
	sum wpratio

restore

* Table B.2 - Descriptive statistics - Baseline
preserve

	*OUTLIERS
	drop if session==7 & period==12 & subject==3
	drop if session==7 & period==18 & subject==3
	drop if session==7 & period==19 & subject==3
	drop if session==9 & period==31 & subject==1

	drop if treatment!=1

	sum interest if subject==1
	sum inflation if subject==1
	sum gap if subject==1
	sum gdp if subject==1
	sum realgdp if subject==1
	sum rgdpg if subject==1

	sum stock
	sum price	
	sum profits
	sum prodfun
	sum sales
	sum prodmsales
	sum wage
	sum dmwage
	sum markup_price
	sum wpratio

restore

* Table B.3 - Descriptive statistics - Human CB
preserve

	*OUTLIERS
	drop if session==7 & period==12 & subject==3
	drop if session==7 & period==18 & subject==3
	drop if session==7 & period==19 & subject==3
	drop if session==9 & period==31 & subject==1

	drop if treatment!=2

	sum interest if subject==1
	sum inflation if subject==1
	sum gap if subject==1
	sum gdp if subject==1
	sum realgdp if subject==1
	sum rgdpg if subject==1

	sum stock
	sum price
	sum profits
	sum prodfun
	sum sales
	sum prodmsales
	sum wage
	sum dmwage
	sum markup_price
	sum wpratio

restore

* Table B.4 - Descriptive statistics - Menu Cost
preserve
	
	*OUTLIERS
	*drop if session==7 & period==12 & subject==3
	*drop if session==7 & period==18 & subject==3
	*drop if session==7 & period==19 & subject==3
	*drop if session==9 & period==31 & subject==1

	drop if treatment!=3
	
	sum interest if subject==1
	sum inflation if subject==1
	sum gap if subject==1
	sum gdp if subject==1
	sum realgdp if subject==1
	sum rgdpg if subject==1

	sum stock
	sum price
	sum profits
	sum prodfun
	sum sales
	sum prodmsales
	sum wage
	sum dmwage
	sum markup_price
	sum wpratio

restore

* Table B.5 - Descriptive statistics - Low Friction
preserve

	*OUTLIERS
	drop if session==7 & period==12 & subject==3
	drop if session==7 & period==18 & subject==3
	drop if session==7 & period==19 & subject==3
	drop if session==9 & period==31 & subject==1

	drop if treatment!=4

	sum interest if subject==1
	sum inflation if subject==1
	sum gap if subject==1
	sum gdp if subject==1
	sum realgdp if subject==1
	sum rgdpg if subject==1

	sum stock
	sum price
	sum profits
	sum prodfun
	sum sales
	sum prodmsales
	sum wage
	sum dmwage
	sum markup_price
	sum wpratio

restore



use "$input/exp_data_1-17_ver5.dta", clear

egen shs1=sum(hs1) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)
egen shs2=sum(hs2) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)
egen shs3=sum(hs3) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)

egen sumsavings=sum(savings) if subject==4 | subject==5 | subject==6 | subject==1 | subject==2 | subject==3, by(period session)

gen prod=prodfun/stock

drop if session==1
drop if initializ==1

drop if subject==1
drop if subject==2
drop if subject==3
drop if subject==7
drop if subject==8
drop if subject==9

xtset id period

gen dwage=-labval/stock-agrwage
gen dprice=price-avgpriceall
gen realinterest=interest-inflation

*individual wages
gen wage=-labval/stock

gen work = 10 - stock

*consumption calculation
gen cons=quantity1+quantity2+quantity3
gen consumption=quantity1*pprice1+quantity2*pprice2+quantity3*pprice3

* Table B.6 - Descriptive statistics - Pooled
preserve

	gen wwage=-wage
	sum wwage
	sum stock
	sum work
	sum savings
	sum sumsavings if subject==4
	sum utility

	sum quantity1
	sum quantity2
	sum quantity3
	sum cons
	sum consumption

restore

* Table B.7 - Descriptive statistics - Baseline
preserve
	drop if treatment!=1
	
	gen wwage=-wage
	sum wwage
	sum stock
	sum work
	sum savings
	sum sumsavings if subject==4
	sum utility

	sum quantity1
	sum quantity2
	sum quantity3
	sum cons
	sum consumption

restore

* Table B.8 - Descriptive statistics - Human CB
preserve
	drop if treatment!=2
	
	gen wwage=-wage
	sum wwage
	sum stock
	sum work
	sum savings
	sum sumsavings if subject==4
	sum utility

	sum quantity1
	sum quantity2
	sum quantity3
	sum cons
	sum consumption

restore

* Table B.9 - Descriptive statistics - Menui Cost
preserve
	drop if treatment!=3
	
	gen wwage=-wage
	sum wwage
	sum stock
	sum work
	sum savings
	sum sumsavings if subject==4
	sum utility

	sum quantity1
	sum quantity2
	sum quantity3
	sum cons
	sum consumption

restore

* Table B.10 - Descriptive statistics - Pooled
preserve
	drop if treatment!=4
	
	gen wwage=-wage
	sum wwage
	sum stock
	sum work
	sum savings
	sum sumsavings if subject==4
	sum utility

	sum quantity1
	sum quantity2
	sum quantity3
	sum cons
	sum consumption

restore
